'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _CloseIcon = require('../CloseIcon');

var _CloseIcon2 = _interopRequireDefault(_CloseIcon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @category communication
 * @component alert
 * @variations collab-ui-react
 */

var Alert = function Alert(props) {
  var show = props.show,
      type = props.type,
      closable = props.closable,
      onHide = props.onHide,
      title = props.title,
      message = props.message;


  return show && _react2.default.createElement(
    'div',
    { className: 'cui-alert' + (' cui-alert--' + type) },
    _react2.default.createElement(
      'div',
      { className: 'cui-alert__title' },
      title
    ),
    _react2.default.createElement(
      'div',
      { className: 'cui-alert__message' },
      message
    ),
    closable && _react2.default.createElement(_CloseIcon2.default, { onClick: onHide })
  );
};

Alert.defaultProps = {
  title: '',
  message: '',
  type: 'info',
  closable: false,
  onHide: function onHide() {}
};

Alert.displayName = 'Alert';

exports.default = Alert;

/**
* @name Alerts
* @description Create the type of Alert (infor, success, warning, or error) by passing in the type prop.
*
* @category communication
* @component alert
* @section default
*
* @js

import {
  Button
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showAlert: false,
    alertType: 'info'
  }

  render() {
    return (
      <section>
        <div>
          <div className='row'>
            <br />
            <Button
              label='Click to Trigger Success Alert'
              ariaLabel='Click to Trigger'
              onClick={() => this.setState({ showAlert: true, alertType: 'info' })}
              label='Info/Default'
              ariaLabel='Open Modal'
              color='primary'
              size='large'
            />
          <div className='row'>
          </div>
            <br />
            <Button
              label='Click to Trigger Success Alert'
              ariaLabel='Click to Trigger'
              onClick={() => this.setState({ showAlert: true, alertType: 'success' })}
              label='Success'
              ariaLabel='Open Modal'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              label='Click to Trigger Warning Alert'
              ariaLabel='Click to Trigger'
              onClick={() => this.setState({ showAlert: true, alertType: 'warning' })}
              label='Warning'
              ariaLabel='Open Modal'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              label='Click to Trigger Error Alert'
              ariaLabel='Click to Trigger'
              onClick={() => this.setState({ showAlert: true, alertType: 'error' })}
              label='Error'
              ariaLabel='Open Modal'
              color='primary'
              size='large'
            />
          </div>
        </div>
        <br />
        <Alert
          type={this.state.alertType}
          show={this.state.showAlert}
          closable
          onHide={() => this.setState({ showAlert: false })}
          title='Alert'
          message={'I\'m an Alert'}
        />
      </section>
    );
  }
}

**/

module.exports = exports['default'];